@@ -253,7 +253,11 @@ bsmc2.internal <- function (object, Np, smooth, ..., verbose, .gnsi = TRUE) {
     gnsi <- FALSE  ## all native symbols have been looked up
 
     ## the following is triggered by the first illegal weight value
-    xx <- is.finite(weights) | isTRUE(weights==-Inf)
+    xx <- vapply(
+      as.numeric(weights),
+      function (x) is.finite(x)||isTRUE(x==-Inf),
+      logical(1)
+    )
     if (!all(xx)) {
       xx <- which(!xx)[1L]
       illegal_dmeasure_error(
