@@ -11,21 +11,21 @@ void set_pomp_userdata (SEXP userdata) {
 
 const SEXP get_userdata (const char *name) {
   SEXP elt = getPairListElement(USERDATA,name);
-  if (isNull(elt)) errorcall(R_NilValue,"no user-data element '%s' is found.",name);
+  if (isNull(elt)) err("no user-data element '%s' is found.",name);
   return elt;
 }
 
 const int *get_userdata_int (const char *name) {
   SEXP elt = getPairListElement(USERDATA,name);
-  if (isNull(elt)) errorcall(R_NilValue,"no user-data element '%s' is found.",name);
-  if (!isInteger(elt)) errorcall(R_NilValue,"user-data element '%s' is not an integer.",name);
+  if (isNull(elt)) err("no user-data element '%s' is found.",name);
+  if (!isInteger(elt)) err("user-data element '%s' is not an integer.",name);
   return INTEGER(elt);
 }
 
 const double *get_userdata_double (const char *name) {
   SEXP elt = getPairListElement(USERDATA,name);
-  if (isNull(elt)) errorcall(R_NilValue,"no user-data element '%s' is found.",name);
-  if (!isReal(elt)) errorcall(R_NilValue,"user-data element '%s' is not a numeric vector.",name);
+  if (isNull(elt)) err("no user-data element '%s' is found.",name);
+  if (!isReal(elt)) err("user-data element '%s' is not a numeric vector.",name);
   return REAL(elt);
 }
 
